#' @export
pls::pcr

#' @export
pls::plsr

#' @importFrom pls MSEP
#' @export
pls::MSEP

#' @importFrom pls R2
#' @export
pls::R2
  
#' @importFrom pls RMSEP
#' @export
pls::RMSEP

#' @export
pls::coefplot
  
#-#' @export
# pls::corrplot
  
#' @export
pls::cvsegments
  
#' @export
pls::loading.weights

#' @export
pls::loadingplot
  
#' @export
pls::loadings

#' @importFrom pls mvrValstats
#' @export
pls::mvrValstats

#' @export
pls::predplot

#' @export
pls::scoreplot

#' @export
pls::scores

#' @export
pls::validationplot
